{% extends 'snowebsvg/common/svg.html' %}

{% block svg_viewbox %}0 0 120 200{% endblock %}
{% block svg_aspect_ratio %}xMidYMid slice{% endblock %}
{% block svg_class %}{{ block.super }} svg-bg{% endblock %}

{% block svg_content %}
    <filter id="{{ self.key_composer }}-blur" x="0" y="0">
        <feGaussianBlur in="SourceAlpha" stdDeviation="1"></feGaussianBlur>
    </filter>

    <g opacity="0.15">
        <circle filter="url(#{{ self.key_composer }}-blur)"
                class="svg-fill-tertiary svg-builder-circle"
                cx="97.78"
                cy="22.22"
                r="22.22">
        </circle>
        <circle filter="url(#{{ self.key_composer }}-blur)"
                class="svg-fill-tertiary svg-builder-circle"
                cx="38.35"
                cy="38.35"
                r="38.35">
        </circle>
        <circle filter="url(#{{ self.key_composer }}-blur)"
                class="svg-fill-tertiary svg-builder-circle"
                cx="22.22"
                cy="177.78"
                r="22.22">
        </circle>
        <circle filter="url(#{{ self.key_composer }}-blur)"
                class="svg-fill-tertiary svg-builder-circle"
                cx="81.65"
                cy="161.65"
                r="38.35">
        </circle>
        <circle filter="url(#{{ self.key_composer }}-blur)"
                class="svg-fill-tertiary svg-builder-circle"
                cx="100.07"
                cy="107.39"
                r="11.82">
        </circle>
        <circle filter="url(#{{ self.key_composer }}-blur)"
                class="svg-fill-tertiary svg-builder-circle"
                cx="18.66"
                cy="107.39"
                r="11.82">
        </circle>
    </g>

{% endblock %}
