<circle class="svg-fill-primary" cx="11.47" cy="50" r="11.47"></circle>
<circle class="svg-fill-primary" cx="50" cy="50" r="11.47"></circle>
<circle class="svg-fill-primary" cx="88.53" cy="50" r="11.47"></circle>
