{% load svg %}<a class="svg-trigger" style="text-decoration: none"
                 href="{% url 'app:svg' self.group.collection.key self.group.key self.key %}">
    <article class="svg-effect-builder"
             style="background: rgba(255,255,255,0.25);backdrop-filter: blur( 4px );-webkit-backdrop-filter: blur( 4px );max-width: 200px; margin: 20px;">
        {% svg_inline self theme variant=variant %}
        <div class="svg-effect-container" style="padding: 10px">
            <svg class="svg-snoweb svg-theme-{% if theme == 'light' %}light{% else %}dark{% endif %}"
                 style="width: 100%;" viewBox="0 0 1920 1080">
                <rect stroke-width="3" width="1920" height="1080" class="svg-fill-tertiary svg-stroke-primary"></rect>
            </svg>
            <h2>{% lorem 5 w random %}</h2>
            <p style="color: var(--text-bright)">{% lorem 10 w random %}</p>
        </div>
    </article>
</a>
