{{ start }} load svg {{ end }}

{% block content %}<a href="#" class="svg-trigger">
        <div class="svg-effect-builder">

            {{ start }} svg_inline '{{ self.key_composer }}' '{{ theme }}' '{{ size }}'{% if variant %} '{{ variant }}'{% endif %} {{ end }}

            ...

        </div>
</a>{% endblock %}