{% extends 'snowebsvg/common/builders/circle.html' %}

{% block builder_base %}
    {% include 'snowebsvg/common/svg/caret/base.html' %}
{% endblock %}

{% block builder_hover %}
    {% include 'snowebsvg/common/svg/caret/hover.html' %}
{% endblock %}
