{% extends 'snowebsvg/common/builders/basic.html' %}

{% load svg_utils %}

{% block svg_content %}

    <clipPath id="clip-path-{{ self.key_composer }}">
        <rect x="0" y="0" width="100" height="100" rx="15" ry="15"></rect>
    </clipPath>

    <g clip-path="url(#clip-path-{{ self.key_composer }})">

        {% comment %}We transform here because of `stdDeviation` of blur{% endcomment %}
        {% if variant == 'glass' %}<g transform="{% scale 0.8 %}">{% endif %}

        <rect {% variant_manager variant self 'attrs' %}
                class="svg-fill-tertiary"
                x="0"
                y="0"
                width="100"
                height="100"
                rx="15"
                ry="15"
        >
        </rect>

        {% if variant == 'glass' %}</g>{% endif %}

        <g transform="{% scale 1.45 %}">
            <circle {% variant_manager variant self 'attrs' %}
                    class="svg-fill-secondary svg-builder-circle"
                    cx="50"
                    cy="50"
                    r="50">
            </circle>
        </g>

    </g>

    <g transform="{% scale 0.5 %}">
        {{ block.super }}
    </g>

{% endblock %}
