<rect class="svg-fill-primary" x="28.76" y="11.53" width="71.24" height="14.5"></rect>
<rect class="svg-fill-primary" x="28.76" y="43.4" width="71.24" height="14.5"></rect>
<rect class="svg-fill-primary" x="28.76" y="73.97" width="71.24" height="14.5"></rect>
<rect class="svg-fill-primary" y="11.53" width="14.5" height="14.5"></rect>
<rect class="svg-fill-primary" y="43.4" width="14.5" height="14.5"></rect>
<rect class="svg-fill-primary" y="73.97" width="14.5" height="14.5"></rect>
