{% extends 'snowebsvg/common/svg.html' %}

{% load svg_utils %}

{% block svg_viewbox %}0 0 120 200{% endblock %}
{% block svg_aspect_ratio %}xMidYMid slice{% endblock %}
{% block svg_class %}{{ block.super }} svg-bg{% endblock %}

{% block svg_content %}
    <filter id="{{ self.key_composer }}-blur" x="0" y="0">
        <feGaussianBlur in="SourceAlpha" stdDeviation="1"></feGaussianBlur>
    </filter>

    <g opacity="0.15" transform="{% scale 2.35 x=60 y=100 %}">
        <circle filter="url(#{{ self.key_composer }}-blur)"
                class="svg-fill-tertiary svg-builder-circle"
                cx="60"
                cy="100"
                r="0">
        </circle>
    </g>

{% endblock %}
