{% extends 'snowebsvg/common/styles.html' %}

{% block css %}{{ block.super }}<link rel="stylesheet" href="{{ settings.BASE_URL_CSS }}essential-{{ settings.VERSION }}.css">
<link rel="stylesheet" href="{{ settings.BASE_URL_CSS }}effect-{{ settings.VERSION }}.css">{% endblock %}
