{% extends 'snowebsvg/common/builders/line.html' %}

{% block builder_base %}
    <g transform="rotate(180, 50, 50)">
        {% include 'snowebsvg/common/svg/angle/base.html' %}
    </g>
{% endblock %}

{% block builder_hover %}
    <g transform="rotate(180, 50, 50)">
        {% include 'snowebsvg/common/svg/angle/hover.html' %}
    </g>
{% endblock %}
