<rect class="svg-fill-primary" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" x="37.88" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" x="75.76" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" y="37.88" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" x="37.88" y="37.88" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" x="75.76" y="37.88" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" y="75.76" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" x="37.88" y="75.76" width="24.24" height="24.24"></rect>
<rect class="svg-fill-primary" x="75.76" y="75.76" width="24.24" height="24.24"></rect>
