{% extends 'snowebsvg/common/builders/basic.html' %}

{% load svg_utils %}

{% block svg_content %}

    <clipPath id="clip-path-{{ self.key_composer }}">
        <rect x="0" y="95" width="100" height="5"></rect>
    </clipPath>


    <g clip-path="url(#clip-path-{{ self.key_composer }})">

        <rect {% variant_manager variant self 'attrs' %}
                class="svg-fill-tertiary"
                x="0"
                y="95"
                width="100"
                height="5">
        </rect>

        <g transform="translate(0, 50)">
            <circle {% variant_manager variant self 'attrs' %}
                    class="svg-fill-secondary svg-builder-circle"
                    cx="50"
                    cy="50"
                    r="50">
            </circle>
        </g>
    </g>
    <g transform="{% scale 0.5 %}">
        {{ block.super }}
    </g>
{% endblock %}
